
volatile int count;
volatile bool incrementCounter;

volatile bool PB0_state = HIGH;
volatile bool PB1_state = HIGH;
volatile bool PB2_state = HIGH;

#define MAX_VAL       10

#define BUZZER        7

#define BUTON_START   8
#define BUTON1        9
#define BUTON2        10

void configPinChangeInterrupts()
{
    PCICR   |= (1 << PCIE0);
    PCMSK0  |= (1 << PCINT0);
    PCMSK0  |= (1 << PCINT1);
    PCMSK0  |= (1 << PCINT2);
}

void configTimer()
{
    incrementCounter = false;
    
    TCCR1B = 0;
    TCCR1A = 0;
  
    OCR1A = 62500;
    TCCR1B |= (1 << WGM12);   
    TCCR1B |= (1 << CS12);
    TIMSK1 &= ~(1 << OCIE1A); 
}


void initTimer()
{
      TCNT1  = 0;
      count = 0;
      TIMSK1 |= (1 << OCIE1A);
}

void stopTimer()
{
      TCNT1  = 0;
      count = 0;
      TIMSK1 &= ~(1 << OCIE1A);
}

void startBuzzer()
{
      incrementCounter = false;
      stopTimer();
      tone(BUZZER, 450);
      initTimer();
}

void stopBuzzer()
{
    noTone(BUZZER);
    stopTimer();
}

void setup() {
  
    Serial.begin(9600);

    /* buton de start */
    pinMode(BUTON_START, INPUT_PULLUP);

    /* butoanele jucatorilor */
    pinMode(BUTON1, INPUT_PULLUP);
    pinMode(BUTON2, INPUT_PULLUP);

    /* configurare intreruperi de tip
    *  pin change pentru cele 3 butoane */
    configPinChangeInterrupts();

    cli();
    /* configurare timer */
    configTimer();
    sei();
}

ISR(TIMER1_COMPA_vect)
{ 
  if(incrementCounter)
  {
    count ++;
    if(count > MAX_VAL)
    {
        startBuzzer();  
    }
    else
    {
        Serial.println(count);
    }
  }
  else 
  {
      stopBuzzer();
  }
}

ISR(PCINT0_vect)
{
  if(!digitalRead(BUTON_START) && PB0_state)
  { 
    /* buton de start apasat */
    PB0_state = LOW;
    incrementCounter = true;
    initTimer();
  }
  else if(digitalRead(BUTON_START) && !PB0_state)
  {
    PB0_state = HIGH;
  }

  if(!digitalRead(BUTON1) && PB1_state)
  {
    /* buton 1 apasat */
    PB1_state = LOW;
    if(incrementCounter)
    {
        startBuzzer();
    }
  }
  else if(digitalRead(BUTON1) && !PB1_state)
  {
    PB1_state = HIGH;
  }

  if(!digitalRead(BUTON2) && PB2_state)
  {
    /* buton 2 apasat */
    PB2_state = LOW;
    if(incrementCounter)
    {
        startBuzzer();
    }
  }
  else if(digitalRead(BUTON2) && !PB2_state)
  {
     PB2_state = HIGH;
  }
}

void loop() {

}
